@@ -1,12 +1,12 @@
-# unpack --- extracts network object into 
-# a list
-# INPUT = network object
-# OUTPUT = list of network model components
-# S. Borrett and M. Lau | July 2011
-# ------------------------------------
+#' unpack --- extracts network object into
+#' a list
+#' INPUT = network object
+#' OUTPUT = list of network model components
+#' S. Borrett and M. Lau | July 2011
+#' ------------------------------------
 
 unpack <- function(x='network object'){
-  flow <- x%n%'flow'  
+  flow <- as.matrix(x, attrname = 'flow')
   input <- x%v%'input'
   respiration <- x%v%'respiration'
   respiration[is.na(respiration)] <- 0
